from flask import request
from flask_restx import Resource, Namespace, reqparse

from app.defines import StatesCode

ns = Namespace('users', description='用户管理接口')

get_users = reqparse.RequestParser(bundle_errors=True)
get_users.add_argument(name='status', type=float, required=True, location='args', help='用户状态')
get_users.add_argument(name='page_size', type=int, location='args', required=False, help='每页记录数量，默认:20')
get_users.add_argument(name='page', type=int, location='args', required=False, help='第几页')


@ns.route('/user_list')
class GetUserListApi(Resource):
    @ns.doc(id='get_users_list', description='获取用户列表')
    @ns.expect(get_users)
    def get(self):
        """获取用户列表"""
        status = request.args.get('status')
        page_size = int(request.args.get('page_size', 20))
        page = int(request.args.get('page', 1))
        data = [
            {"user_name": "admin", "mobile": "13912345678", "email": "admin@qq.com", "role": "admin", "permission": 1,
             "unit": "北京电信规划院", "registration_time": "2020-01-01 10:10"},
            {"user_name": "admin1", "mobile": "13912345679", "email": "admin1@qq.com", "role": "admin", "permission": 1,
             "unit": "北京电信", "registration_time": "2020-01-01 11:10"},
        ]
        return {"code": StatesCode.SUCCESS, "message": "成功", "data": data}


@ns.route('/user')
class UsersApi(Resource):
    @ns.doc(id='query_users', description='搜索用户')
    @ns.expect()
    def get(self):
        """查询用户"""
        data = [
            {"user_name": "admin", "mobile": "13912345678", "email": "admin@qq.com", "role": "admin", "permission": 1,
             "unit": "北京电信规划院", "registration_time": "2020-01-01 10:10"},
            # {"user_name": "admin1", "mobile": "13912345679", "email": "admin1@qq.com", "role": "admin", "permission": 1,
            #  "unit": "北京电信", "registration_time": "2020-01-01 11:10"},
        ]
        return {"code": StatesCode.SUCCESS, "message": "成功", "data": data}

    @ns.doc(id='add_users', description='添加用户')
    @ns.expect()
    def post(self):
        """添加用户"""
        return {"code": StatesCode.SUCCESS, "message": "成功", "data": "user002"}

    @ns.doc(id='modify_users_details', description='修改用户状态，激活、禁用')
    @ns.expect()
    def put(self):
        """修改用户状态，激活、禁用"""
        return {"code": StatesCode.SUCCESS, "message": "成功", "data": ""}

    @ns.doc(id='delete_users', description='删除用户')
    @ns.expect()
    def delete(self):
        """删除用户"""
        return {"code": StatesCode.SUCCESS, "message": "成功", "data": "user003"}


@ns.route('/user_details')
class GetUsersApi(Resource):
    @ns.doc(id='get_users_details', description='获取用户详情')
    @ns.expect()
    def get(self):
        """获取用户详情"""
        data = \
            {
                "user_name": "admin",
                "password": "123",
                "name": "张三",
                "mobile": "13912345678",
                "email": "admin@qq.com",
                "unit": "北京电信规划院",
                "division": "研发中心",
                "role": "admin",
                "permission": 1,
                "status_in_office": 1,
                "position": "部门主管",
                "account_status": 1,
                "nationality": "中国"
            },

        return {"code": StatesCode.SUCCESS, "message": "成功", "data": data}

    @ns.doc(id='update_users_details', description='更新用户详情')
    @ns.expect()
    def put(self):
        """更新用户详情"""
        return {"code": StatesCode.SUCCESS, "message": "成功", "data": ""}


@ns.route('/batch_delete_user')
class BatchDeleteUserApi(Resource):
    @ns.doc(id='batch_delete_users', description='批量删除用户')
    @ns.expect()
    def delete(self):
        """批量删除用户"""

        return {"code": StatesCode.SUCCESS, "message": "成功", "data": "user004"}


@ns.route('/batch_modify_user_status')
class BatchModifyUsersStatusApi(Resource):
    @ns.doc(id='get_users_details', description='批量修改用户状态，激活、禁用')
    @ns.expect()
    def put(self):
        """批量修改用户状态，激活、禁用"""
        return {"code": StatesCode.SUCCESS, "message": "成功", "data": ""}


@ns.route('/export_data')
class ExportDataApi(Resource):
    @ns.doc(id='export_data', description='导出用户数据')
    @ns.expect()
    def get(self):
        """导出用户数据"""
        return {"code": StatesCode.SUCCESS, "message": "成功", "data": ""}
